@@ -35,14 +35,23 @@ import com.google.gwt.user.client.ui.HTML;
 import com.google.gwt.user.client.ui.Widget;
 
 /**
- * Form used to add resource(s) to a dataset
+ * The Class AddResourceToDataset.
+ *
+ * @author Francesco Mangiacrapa at ISTI-CNR francesco.mangiacrapa@isti.cnr.it
  * 
- * @author Costantino Perciante at ISTI-CNR (costantino.perciante@isti.cnr.it)
+ *         Feb 23, 2024
  */
 public class AddResourceToDataset extends Composite {
 
 	private static AddResourceToDatasetUiBinder uiBinder = GWT.create(AddResourceToDatasetUiBinder.class);
 
+	/**
+	 * The Interface AddResourceToDatasetUiBinder.
+	 *
+	 * @author Francesco Mangiacrapa at ISTI-CNR francesco.mangiacrapa@isti.cnr.it
+	 * 
+	 *         Feb 23, 2024
+	 */
 	interface AddResourceToDatasetUiBinder extends UiBinder<Widget, AddResourceToDataset> {
 	}
 
@@ -82,6 +91,15 @@ public class AddResourceToDataset extends Composite {
 
 	FlowPanel alertPanel = new FlowPanel();
 
+	/**
+	 * Instantiates a new adds the resource to dataset.
+	 *
+	 * @param eventBus     the event bus
+	 * @param datasetId    the dataset id
+	 * @param datasetTitle the dataset title
+	 * @param datasetOrg   the dataset org
+	 * @param datasetUrl   the dataset url
+	 */
 	public AddResourceToDataset(HandlerManager eventBus, final String datasetId, String datasetTitle,
 			final String datasetOrg, final String datasetUrl) {
 		initWidget(uiBinder.createAndBindUi(this));
@@ -115,6 +133,9 @@ public class AddResourceToDataset extends Composite {
 
 	}
 
+	/**
+	 * Bind.
+	 */
 	private void bind() {
 
 		eventBus.addHandler(WorkspaceItemSelectedEvent.TYPE, new WorkspaceItemSelectedEventHandler() {
@@ -149,6 +170,11 @@ public class AddResourceToDataset extends Composite {
 
 	}
 
+	/**
+	 * On select from workspace click.
+	 *
+	 * @param e the e
+	 */
 	@UiHandler("buttoSelectFromWorkspace")
 	void onSelectFromWorkspaceClick(ClickEvent e) {
 
@@ -165,6 +191,11 @@ public class AddResourceToDataset extends Composite {
 		dialog.center();
 	}
 
+	/**
+	 * On add button click.
+	 *
+	 * @param e the e
+	 */
 	@UiHandler("addResourceButton")
 	void onAddButtonClick(ClickEvent e) {
 
@@ -216,7 +247,7 @@ public class AddResourceToDataset extends Composite {
 				infoPanel.clear();
 
 				if (result != null) {
-					showAlert("Resource created correctly", null, AlertType.SUCCESS, true, true);
+					showAlert("Resource added correctly", null, AlertType.SUCCESS, true, true);
 					eventBus.fireEvent(new AddResourceEvent(result));
 					eventBus.fireEvent(new ReloadDatasetPageEvent(datasetId));
 
@@ -228,8 +259,7 @@ public class AddResourceToDataset extends Composite {
 				} else
 					showAlert("Unable to add this resource. Check that the url is correct", null, AlertType.ERROR, true,
 							true);
-				
-				
+
 				addResourceButton.setEnabled(true);
 
 			}
@@ -239,7 +269,7 @@ public class AddResourceToDataset extends Composite {
 				infoPanel.clear();
 				showAlert("Unable to add this resource, sorry. Error is: " + caught.getMessage(), null, AlertType.ERROR,
 						true, true);
-				
+
 				addResourceButton.setEnabled(true);
 
 			}
@@ -249,9 +279,12 @@ public class AddResourceToDataset extends Composite {
 
 	/**
 	 * Show error/success after resource creation attempt.
-	 * 
-	 * @param text
-	 * @param type
+	 *
+	 * @param text         the text
+	 * @param loader       the loader
+	 * @param type         the type
+	 * @param scheduleHide the schedule hide
+	 * @param setVisible   the set visible
 	 */
 	protected void showAlert(String text, LoaderIcon loader, AlertType type, boolean scheduleHide, boolean setVisible) {
 
