@@ -29,6 +29,7 @@ import org.gcube.datacatalogue.utillibrary.shared.jackan.model.CkanDataset;
 import org.gcube.datacatalogue.utillibrary.shared.jackan.model.CkanGroup;
 import org.gcube.datacatalogue.utillibrary.shared.jackan.model.CkanLicense;
 import org.gcube.datacatalogue.utillibrary.shared.jackan.model.CkanOrganization;
+import org.gcube.datacatalogue.utillibrary.shared.jackan.model.CkanPair;
 import org.gcube.datacatalogue.utillibrary.shared.jackan.model.CkanResource;
 import org.gcube.datacatalogue.utillibrary.shared.jackan.model.CkanTag;
 import org.gcube.portlets.user.uriresolvermanager.UriResolverManager;
@@ -485,9 +486,12 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 			}
 			bean.setResources(list);
 		}
-
+		
+		logger.debug("extras are #: "+dataset.getExtras().size());
 		// Settings the dataset type
 		Map<String, List<String>> extras = dataset.getListExtrasAsHashMap();
+		printExtras(dataset);
+	
 		if (extras != null) {
 			List<String> theDatasetType = extras.get(SYS_TYPE);
 			if (theDatasetType != null && theDatasetType.size() > 0) {
@@ -499,6 +503,18 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 		logger.info("Returning the bean for dataset title {} and type {}" + bean.getTitle(), bean.getChosenType());
 		return bean;
 	}
+	
+	private void printExtras(CkanDataset dataset) {
+		if(logger.isDebugEnabled()) {
+			logger.trace("extras are: "+dataset.getExtras());
+			if (dataset.getExtras() != null) {
+				int i = 0;
+				for (CkanPair cp : dataset.getExtras()) {
+					logger.debug(++i+") key:" + cp.getKey() + ", value: "+cp.getValue());
+				}
+			}
+		}
+	}
 
 	/**
 	 * Discover from the IS the vocabulary of tags for this scope, if present.
@@ -1277,7 +1293,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 			String scopePerCurrentUrl = GenericUtils.getScopeFromClientUrl(getThreadLocalRequest());
 
 			if (!isWithinPortal()) {
-				role = RolesCkanGroupOrOrg.EDITOR;
+				role = RolesCkanGroupOrOrg.ADMIN;
 				logger.warn("OUT FROM PORTAL SETTING HARD-CODED ROLE " + role);
 			} else {
 				String keyPerScopeRole = CatalogueUtilMethods
